@@ -1,16 +1,17 @@
-from console_base.choices import LCTextChoices
+from console_base.choices import LCTextChoicesMixin
+from django.db.models import TextChoices
 from django.utils.translation import gettext_lazy as _
 
 
 # ---------------------------------------------------------------------------
-class CONTEXT(LCTextChoices):
+class CONTEXT(LCTextChoicesMixin, TextChoices):
     Event = 'pgh_context', 'Context from local Concord Event'
     Origin = 'origin_context', "Subscriber's original Concord Event Context"
     Keys = 'keys', "Context Keys from Subscriber's Event Context"
 
 
 # ---------------------------------------------------------------------------
-class SYNCMODES(LCTextChoices):
+class SYNCMODES(LCTextChoicesMixin, TextChoices):
     """
     Should records be deleted on the local console only,
     or synchronized among all the consoles?
@@ -20,7 +21,7 @@ class SYNCMODES(LCTextChoices):
 
 
 # ---------------------------------------------------------------------------
-class CRUD(LCTextChoices):
+class CRUD(LCTextChoicesMixin, TextChoices):
     Create = 'create', 'Create'
     Update = 'update', 'Update'
     Delete = 'delete', 'Delete'
@@ -28,6 +29,6 @@ class CRUD(LCTextChoices):
 
 
 # ---------------------------------------------------------------------------
-class ORIGIN_SERVER(LCTextChoices):
+class ORIGIN_SERVER(LCTextChoicesMixin, TextChoices):
     CID = 'origin_server_cid', _('Origin Appliance / Server CID')
     Name = 'origin_server_name', _('Origin Appliance / Server Name')
